@@ -56,6 +56,10 @@
 #include "welle-cli/jsonconvert.h"
 #include "welle-cli/webprogrammehandler.h"
 
+#include "index.html.h"
+#include "index.js.h"
+#include "favicon.ico.h"
+
 #ifdef __unix__
 # include <unistd.h>
 # if _POSIX_VERSION >= 200809L
@@ -89,6 +93,7 @@ static const char* http_405 = "HTTP/1.0 405 Method Not Allowed\r\n";
 static const char* http_500 = "HTTP/1.0 500 Internal Server Error\r\n";
 static const char* http_503 = "HTTP/1.0 503 Service Unavailable\r\n";
 static const char* http_contenttype_mp3 = "Content-Type: audio/mpeg\r\n";
+static const char* http_contenttype_flac = "Content-Type: audio/flac\r\n";
 static const char* http_contenttype_m3u = "Content-Type: application/mpegurl\r\n";
 static const char* http_contenttype_text = "Content-Type: text/plain\r\n";
 static const char* http_contenttype_data =
@@ -103,14 +108,17 @@ static const char* http_contenttype_js =
 static const char* http_contenttype_html =
         "Content-Type: text/html; charset=utf-8\r\n";
 
+static const char* http_contenttype_ico =
+        "Content-Type: image/x-icon\r\n";
+
 static const char* http_nocache = "Cache-Control: no-cache\r\n";
 
 static string to_hex(uint32_t value, int width)
 {
-    std::stringstream sidstream;
+    stringstream sidstream;
     sidstream << "0x" <<
-        std::setfill('0') << std::setw(width) <<
-        std::hex << value;
+        setfill('0') << setw(width) <<
+        hex << value;
     return sidstream.str();
 }
 
@@ -187,7 +195,7 @@ void WebRadioInterface::check_decoders_required()
             const auto sid = s.serviceId;
 
             try {
-                const bool is_active = std::find_if(
+                const bool is_active = find_if(
                         carousel_services_active.cbegin(),
                         carousel_services_active.cend(),
                         [&](const ActiveCarouselService& acs) {
@@ -240,7 +248,7 @@ void WebRadioInterface::check_decoders_required()
     phs_changed.notify_all();
 }
 
-void WebRadioInterface::retune(const std::string& channel)
+void WebRadioInterface::retune(const string& channel)
 {
     // Ensure two closely occurring retune() calls don't get stuck
     unique_lock<mutex> retune_lock(retune_mut);
@@ -419,7 +427,7 @@ static http_request_t parse_http_headers(Socket& s) {
         constexpr auto CL = "Content-Length";
         if (r.headers.count(CL) == 1) {
             try {
-                const int content_length = std::stoi(r.headers[CL]);
+                const int content_length = stoi(r.headers[CL]);
                 if (content_length > 1024 * 1024) {
                     cerr << "Unreasonable POST Content-Length: " << content_length << endl;
                     return r;
@@ -462,10 +470,13 @@ bool WebRadioInterface::dispatch_client(Socket&& client)
     else {
         if (req.is_get) {
             if (req.url == "/") {
-                success = send_file(s, "index.html", http_contenttype_html);
+                success = send_file(s, index_html, index_html_len, http_contenttype_html);
             }
             else if (req.url == "/index.js") {
-                success = send_file(s, "index.js", http_contenttype_js);
+                success = send_file(s, index_js, index_js_len, http_contenttype_js);
+            }
+            else if (req.url == "/favicon.ico") {
+                success = send_file(s, favicon_ico, favicon_ico_len, http_contenttype_ico);
             }
             else if (req.url == "/mux.json") {
                 success = send_mux_json(s);
@@ -497,18 +508,42 @@ bool WebRadioInterface::dispatch_client(Socket&& client)
                 return false;
             }
             else {
+                bool url_handled = false;
                 const regex regex_slide(R"(^[/]slide[/]([^ ]+))");
-                std::smatch match_slide;
-
-                const regex regex_mp3(R"(^[/]mp3[/]([^ ]+))");
-                std::smatch match_mp3;
-                if (regex_search(req.url, match_mp3, regex_mp3)) {
-                    success = send_mp3(s, match_mp3[1]);
-                }
-                else if (regex_search(req.url, match_slide, regex_slide)) {
+                smatch match_slide;
+                if (regex_search(req.url, match_slide, regex_slide)) {
                     success = send_slide(s, match_slide[1]);
+                    url_handled = true;
                 }
-                else {
+
+                const regex regex_stream(R"(^[/]stream[/]([^ ]+))");
+                smatch match_stream;
+                if (regex_search(req.url, match_stream, regex_stream)) {
+                    success = send_stream(s, match_stream[1]);
+                    url_handled = true;
+                }
+
+                if (decode_settings.outputCodec == OutputCodec::MP3)
+                {
+                    const regex regex_mp3(R"(^[/]mp3[/]([^ ]+))");
+                    smatch match_mp3;
+                    if (regex_search(req.url, match_mp3, regex_mp3)) {
+                        success = send_stream(s, match_mp3[1]);
+                        url_handled = true;
+                    }
+                }
+
+                if (decode_settings.outputCodec == OutputCodec::FLAC)
+                {
+                    const regex regex_flac(R"(^[/]flac[/]([^ ]+))");
+                    smatch match_flac;
+                    if (regex_search(req.url, match_flac, regex_flac)) {
+                        success = send_stream(s, match_flac[1]);
+                        url_handled = true;
+                    }
+                }
+
+                if (not url_handled) {
                     cerr << "Could not understand GET request " << req.url << endl;
                 }
             }
@@ -540,37 +575,22 @@ bool WebRadioInterface::dispatch_client(Socket&& client)
 }
 
 bool WebRadioInterface::send_file(Socket& s,
-        const std::string& filename,
-        const std::string& content_type)
+        const unsigned char *file,
+        const unsigned int file_length,
+        const string& content_type)
 {
-    FILE *fd = fopen(filename.c_str(), "r");
-    if (fd) {
-        if (not send_http_response(s, http_ok, "", content_type)) {
-            cerr << "Failed to send file headers" << endl;
-            fclose(fd);
-            return false;
-        }
-
-        vector<char> data(1024);
-        ssize_t ret = 0;
-        do {
-            ret = fread(data.data(), 1, data.size(), fd);
-            ret = s.send(data.data(), ret, MSG_NOSIGNAL);
-            if (ret == -1) {
-                cerr << "Failed to send file data" << endl;
-                fclose(fd);
-                return false;
-            }
-
-        } while (ret > 0);
-
-        fclose(fd);
-        return true;
+    if (not send_http_response(s, http_ok, "", content_type)) {
+        cerr << "Failed to send file headers" << endl;
+        return false;
     }
-    else {
-        return send_http_response(s, http_500, "file '" + filename + "' is missing!");
+
+    ssize_t ret = 0;
+    ret = s.send((void*)file, file_length, MSG_NOSIGNAL);
+    if (ret == -1) {
+        cerr << "Failed to send file data" << endl;
+        return false;
     }
-    return false;
+    return true;
 }
 
 static vector<PeakJson> calculate_cir_peaks(const vector<float>& cir_linear)
@@ -752,10 +772,10 @@ bool WebRadioInterface::send_mux_json(Socket& s)
                     m.timestamp.time_since_epoch());
 
             const auto s = duration_cast<seconds>(ms);
-            const std::time_t t = s.count();
-            const std::size_t fractional_seconds = ms.count() % 1000;
+            const time_t t = s.count();
+            const size_t fractional_seconds = ms.count() % 1000;
 
-            ss << std::ctime(&t) << "." << fractional_seconds;
+            ss << ctime(&t) << "." << fractional_seconds;
 
             switch (m.level) {
                 case message_level_t::Information:
@@ -845,7 +865,7 @@ bool WebRadioInterface::send_mux_playlist(Socket& s)
     return true;
 }
 
-bool WebRadioInterface::send_mp3(Socket& s, const std::string& stream)
+bool WebRadioInterface::send_stream(Socket& s, const string& stream)
 {
     unique_lock<mutex> lock(rx_mut);
     ASSERT_RX;
@@ -853,13 +873,27 @@ bool WebRadioInterface::send_mp3(Socket& s, const std::string& stream)
     for (const auto& srv : rx->getServiceList()) {
         if (rx->serviceHasAudioComponent(srv) and
                 (to_hex(srv.serviceId, 4) == stream or
-                (uint32_t)std::stoul(stream) == srv.serviceId)) {
+                (uint32_t)stoul(stream) == srv.serviceId)) {
             try {
                 auto& ph = phs.at(srv.serviceId);
 
                 lock.unlock();
 
-                if (not send_http_response(s, http_ok, "", http_contenttype_mp3)) {
+                string http_contenttype;
+
+                switch (decode_settings.outputCodec)
+                {
+                case OutputCodec::FLAC:
+                    http_contenttype = http_contenttype_flac;
+                    break;
+                case OutputCodec::MP3:
+                    http_contenttype = http_contenttype_mp3;
+                    break;
+                default:
+                    break;
+                }
+
+                if (not send_http_response(s, http_ok, "", http_contenttype)) {
                     cerr << "Failed to send mp3 headers" << endl;
                     return false;
                 }
@@ -889,11 +923,11 @@ bool WebRadioInterface::send_mp3(Socket& s, const std::string& stream)
     return false;
 }
 
-bool WebRadioInterface::send_slide(Socket& s, const std::string& stream)
+bool WebRadioInterface::send_slide(Socket& s, const string& stream)
 {
     for (const auto& wph : phs) {
         if (to_hex(wph.first, 4) == stream or
-                (uint32_t)std::stoul(stream) == wph.first) {
+                (uint32_t)stoul(stream) == wph.first) {
             const auto mot = wph.second.getMOT();
 
             if (mot.data.empty()) {
@@ -921,8 +955,8 @@ bool WebRadioInterface::send_slide(Socket& s, const std::string& stream)
             headers << http_nocache;
 
             headers << "Last-Modified: ";
-            std::time_t t = chrono::system_clock::to_time_t(mot.time);
-            headers << put_time(std::gmtime(&t), "%a, %d %b %Y %T GMT");
+            time_t t = chrono::system_clock::to_time_t(mot.time);
+            headers << put_time(gmtime(&t), "%a, %d %b %Y %T GMT");
             headers << "\r\n";
 
             headers << "\r\n";
@@ -975,7 +1009,7 @@ bool WebRadioInterface::send_impulseresponse(Socket& s)
 
     lock_guard<mutex> lock(plotdata_mut);
     vector<float> cir_db(last_CIR.size());
-    std::transform(last_CIR.begin(), last_CIR.end(), cir_db.begin(),
+    transform(last_CIR.begin(), last_CIR.end(), cir_db.begin(),
             [](float y) { return 10.0f * log10(y); });
 
     size_t lengthBytes = cir_db.size() * sizeof(float);
@@ -1026,7 +1060,7 @@ bool WebRadioInterface::send_spectrum(Socket& s)
     if (samples.size() != (size_t)dabparams.T_u)
         return false;
 
-    std::copy(samples.begin(), samples.end(), spectrumBuffer);
+    copy(samples.begin(), samples.end(), spectrumBuffer);
 
     // Do FFT to get the spectrum
     spectrum_fft_handler.do_FFT();
@@ -1060,13 +1094,13 @@ bool WebRadioInterface::send_constellation(Socket& s)
 {
     const size_t decim = OfdmDecoder::constellationDecimation;
     const size_t num_iqpoints = (dabparams.L-1) * dabparams.K / decim;
-    std::vector<float> phases(num_iqpoints);
+    vector<float> phases(num_iqpoints);
 
     lock_guard<mutex> lock(plotdata_mut);
     if (last_constellation.size() == num_iqpoints) {
         phases.resize(num_iqpoints);
         for (size_t i = 0; i < num_iqpoints; i++) {
-            const float y = 180.0f / (float)M_PI * std::arg(last_constellation[i]);
+            const float y = 180.0f / (float)M_PI * arg(last_constellation[i]);
             phases[i] = y;
         }
 
@@ -1122,7 +1156,7 @@ bool WebRadioInterface::send_channel(Socket& s)
     return true;
 }
 
-bool WebRadioInterface::handle_fft_window_placement_post(Socket& s, const std::string& fft_window_placement)
+bool WebRadioInterface::handle_fft_window_placement_post(Socket& s, const string& fft_window_placement)
 {
     cerr << "POST fft window: " << fft_window_placement << endl;
 
@@ -1168,7 +1202,7 @@ bool WebRadioInterface::handle_fft_window_placement_post(Socket& s, const std::s
     return true;
 }
 
-bool WebRadioInterface::handle_coarse_corrector_post(Socket& s, const std::string& coarseCorrector)
+bool WebRadioInterface::handle_coarse_corrector_post(Socket& s, const string& coarseCorrector)
 {
     cerr << "POST coarse : " << coarseCorrector << endl;
 
@@ -1211,7 +1245,7 @@ bool WebRadioInterface::handle_coarse_corrector_post(Socket& s, const std::strin
     return true;
 }
 
-bool WebRadioInterface::handle_channel_post(Socket& s, const std::string& channel)
+bool WebRadioInterface::handle_channel_post(Socket& s, const string& channel)
 {
     cerr << "POST channel: " << channel << endl;
 
@@ -1242,7 +1276,7 @@ void WebRadioInterface::handle_phs()
         for (auto& s : serviceList) {
             auto scs = rx->getComponents(s);
 
-            if (std::find(
+            if (find(
                         carousel_services_available.cbegin(),
                         carousel_services_available.cend(),
                         s.serviceId) == carousel_services_available.cend()) {
@@ -1254,13 +1288,13 @@ void WebRadioInterface::handle_phs()
             }
 
             if (phs.count(s.serviceId) == 0) {
-                WebProgrammeHandler ph(s.serviceId);
-                phs.emplace(std::make_pair(s.serviceId, move(ph)));
+                WebProgrammeHandler ph(s.serviceId, decode_settings.outputCodec);
+                phs.emplace(make_pair(s.serviceId, move(ph)));
             }
         }
 
         using namespace chrono;
-        size_t max_services_in_carousel = std::min(
+        size_t max_services_in_carousel = min(
                 carousel_services_available.size(),
                 (size_t)decode_settings.num_decoders_in_carousel);
 
@@ -1502,34 +1536,34 @@ void WebRadioInterface::onFIBDecodeSuccess(bool crcCheckOk, const uint8_t* fib)
     new_fib_block_available.notify_one();
 }
 
-void WebRadioInterface::onNewImpulseResponse(std::vector<float>&& data)
+void WebRadioInterface::onNewImpulseResponse(vector<float>&& data)
 {
     lock_guard<mutex> lock(plotdata_mut);
     last_CIR = move(data);
 }
 
-void WebRadioInterface::onNewNullSymbol(std::vector<DSPCOMPLEX>&& data)
+void WebRadioInterface::onNewNullSymbol(vector<DSPCOMPLEX>&& data)
 {
     lock_guard<mutex> lock(plotdata_mut);
     last_NULL = move(data);
 }
 
-void WebRadioInterface::onConstellationPoints(std::vector<DSPCOMPLEX>&& data)
+void WebRadioInterface::onConstellationPoints(vector<DSPCOMPLEX>&& data)
 {
     lock_guard<mutex> lock(plotdata_mut);
     last_constellation = move(data);
 }
 
-void WebRadioInterface::onMessage(message_level_t level, const std::string& text, const std::string& text2)
+void WebRadioInterface::onMessage(message_level_t level, const string& text, const string& text2)
 {
-    std::string fullText;
+    string fullText;
     if (text2.empty())
         fullText = text;
     else
         fullText = text + text2;
     
     lock_guard<mutex> lock(data_mut);
-    const auto now = std::chrono::system_clock::now();
+    const auto now = chrono::system_clock::now();
     pending_message_t m = { .level = level, .text = fullText, .timestamp = now};
     pending_messages.emplace_back(move(m));
 
@@ -1551,7 +1585,7 @@ void WebRadioInterface::onTIIMeasurement(tii_measurement_t&& m)
 
 void WebRadioInterface::onInputFailure()
 {
-    std::exit(1);
+    exit(1);
 }
 
 list<tii_measurement_t> WebRadioInterface::getTiiStats()
@@ -1582,7 +1616,7 @@ list<tii_measurement_t> WebRadioInterface::getTiiStats()
             avg.error = error / len;
 
             // Calculate the median
-            std::nth_element(delays.begin(), delays.begin() + len/2, delays.end());
+            nth_element(delays.begin(), delays.begin() + len/2, delays.end());
             avg.delay_samples = delays[len/2];
         }
         else {
@@ -1593,7 +1627,7 @@ list<tii_measurement_t> WebRadioInterface::getTiiStats()
         l.push_back(move(avg));
     }
 
-    using namespace std::chrono;
+    using namespace chrono;
     const auto now = steady_clock::now();
     // Remove a single entry every second to make the flukes
     // disappear
