@@ -31,6 +31,7 @@
 #include <QSettings>
 #include <QQuickStyle>
 #include <QQmlProperty>
+//#include <neaacdec.h>
 
 #include "gui_helper.h"
 #include "debug_output.h"
@@ -179,8 +180,8 @@ const QByteArray CGUIHelper::getInfoPage(QString pageName)
 
     if (pageName == "Versions") {
         // Set application version
-        InfoContent.append(tr("welle.io version") + ": " + QString(CURRENT_VERSION) + "\n");
-        InfoContent.append(tr("Git revision") + ": " + QString(GITHASH) + "\n");
+        InfoContent.append((tr("welle.io version") + ": " + QString(CURRENT_VERSION) + "\n").toUtf8());
+        InfoContent.append((tr("Git revision") + ": " + QString(GITHASH) + "\n").toUtf8());
         QDateTime tsDT;
         QString source_date_epoch = BUILD_DATE;
         if (!source_date_epoch.isEmpty()) {
@@ -188,8 +189,15 @@ const QByteArray CGUIHelper::getInfoPage(QString pageName)
         } else {
             tsDT = QDateTime::currentDateTime();
         }
-        InfoContent.append(tr("Built on") + ": " + tsDT.toString(Qt::ISODate) + "\n");
-        InfoContent.append(tr("QT version") + ": " + qVersion() + "\n");
+        InfoContent.append((tr("Built on") + ": " + tsDT.toString(Qt::ISODate) + "\n").toUtf8());
+        InfoContent.append((tr("QT version") + ": " + qVersion() + "\n").toUtf8());
+
+        /*char *faad_id_string;
+        char *faad_copyright_string;
+        NeAACDecGetVersion(&faad_id_string, &faad_copyright_string);
+        InfoContent.append((tr("faad2 version") + ": " + faad_id_string + "\n").toUtf8());*/
+        //InfoContent.append((tr("faad2 version") + ": " + FAAD2_VERSION + "\n").toUtf8());
+
         InfoContent.append("\n");
     } else if (pageName == "Authors") {
         return getFileContent(":/AUTHORS");
@@ -603,15 +611,15 @@ void CGUIHelper::openRawFile(QString fileFormat)
 {
 #ifdef __ANDROID__
     // Open file selection dialog
-    const auto ACTION_OPEN_DOCUMENT = QAndroidJniObject::getStaticObjectField<jstring>("android/content/Intent", "ACTION_OPEN_DOCUMENT");
-    QAndroidJniObject intent("android/content/Intent", "(Ljava/lang/String;)V", ACTION_OPEN_DOCUMENT.object());
-    const auto CATEGORY_OPENABLE = QAndroidJniObject::getStaticObjectField<jstring>("android/content/Intent", "CATEGORY_OPENABLE");
+    const auto ACTION_OPEN_DOCUMENT = QJniObject::getStaticObjectField<jstring>("android/content/Intent", "ACTION_OPEN_DOCUMENT");
+    QJniObject intent("android/content/Intent", "(Ljava/lang/String;)V", ACTION_OPEN_DOCUMENT.object());
+    const auto CATEGORY_OPENABLE = QJniObject::getStaticObjectField<jstring>("android/content/Intent", "CATEGORY_OPENABLE");
     intent.callObjectMethod("addCategory", "(Ljava/lang/String;)Landroid/content/Intent;", CATEGORY_OPENABLE.object());
-    intent.callObjectMethod("setType", "(Ljava/lang/String;)Landroid/content/Intent;", QAndroidJniObject::fromString(QStringLiteral("*/*")).object());
+    intent.callObjectMethod("setType", "(Ljava/lang/String;)Landroid/content/Intent;", QJniObject::fromString(QStringLiteral("*/*")).object());
 
     // Open file dialog
     activityResultReceiver = new FileActivityResultReceiver(this, fileFormat);
-    QtAndroid::startActivity( intent.object<jobject>(), 12, activityResultReceiver);
+    QtAndroidPrivate::startActivity( intent.object<jobject>(), 12, activityResultReceiver);
 #else
     (void) fileFormat;
 #endif
@@ -713,7 +721,7 @@ void CGUIHelper::translateGUI(QObject *obj)
 }
 
 #ifdef __ANDROID__
-void FileActivityResultReceiver::handleActivityResult(int receiverRequestCode, int resultCode, const QAndroidJniObject &intent) {
+void FileActivityResultReceiver::handleActivityResult(int receiverRequestCode, int resultCode, const QJniObject &intent) {
     if (!intent.isValid()) {
         return;
     }
@@ -731,178 +739,7 @@ void FileActivityResultReceiver::handleActivityResult(int receiverRequestCode, i
 }
 #endif
 
-QString CGUIHelper::getQQStyleToLoad(QString styleNameArg)  // Static
-{
-    QSettings settings;
-    QString settingStyle = settings.value("qQStyle","").toString();
 
-    // In case this is a first launch where the setting in the config file is not set
-    if (settingStyle.isEmpty()) {
-        if (styleNameArg.isEmpty()) {
-            settings.setValue("qQStyle", "Default");
-            return "Default";
-        }
-        else {
-            settings.setValue("qQStyle", styleNameArg);
-            return styleNameArg;
-        }
-    }
-
-    QStringList availableStyle = QQuickStyle::availableStyles();
-
-    for ( const QString& curStyle : availableStyle ) {
-         if (settingStyle == curStyle)
-             return settingStyle;
-    }
-    if (settingStyle == "System_Auto")
-        return QString();
-    else
-        return "Default";
-}
-
-const QStringList CGUIHelper::qQStyleComboList()
-{
-    if ( !m_comboList.isEmpty() )
-        return m_comboList;
-
-    m_comboList = QQuickStyle::availableStyles();
-    m_comboList.sort();
-    int position = m_comboList.indexOf("Default");
-    m_comboList.move(position, 0);
-    m_comboList.insert(1, "System_Auto");
-
-    QString settingStyle = settings.value("qQStyle","").toString();
-    settingsStyleInAvailableStyles = false;
-
-    for ( const auto& style : m_comboList ) {
-         if (settingStyle == style)
-             settingsStyleInAvailableStyles = true;
-    }
-
-    if ( settingsStyleInAvailableStyles == false ) {
-        m_comboList.append(settingStyle);
-        qDebug() << "Style from the settings " << settingStyle << " not available on system. Adding it to the list of styles and loading 'Default' instead.";
-    }
-
-    return m_comboList;
-}
-
-bool CGUIHelper::isThemableStyle(QString style)
-{
-    return (style == "Universal" || style == "Material");
-}
-
-int CGUIHelper::getIndexOfQQStyle(QString style)
-{
-    //qDebug() << "getIndexOfQQStyle: " << style;
-    return m_comboList.indexOf(style);
-}
-
-QString CGUIHelper::getQQStyle()
-{
-    return settings.value("qQStyle","").toString();
-}
-
-void CGUIHelper::saveQQStyle(int index)
-{
-    //qDebug() << "saveQQStyle : " << index;
-    settings.setValue("qQStyle",m_comboList.value(index));
-    emit styleChanged();
-}
-
-StyleModel::StyleModel(QObject *parent)
-    : QAbstractListModel(parent)
-{
-}
-
-StyleModel* CGUIHelper::qQStyleComboModel()
-{
-    if (m_styleModel != nullptr)
-        m_styleModel = nullptr;
-
-    QString settingStyle = settings.value("qQStyle","").toString();
-
-    QStringList styleList = qQStyleComboList();
-
-    m_styleModel = new StyleModel();
-    for ( const auto& style : styleList  ) {
-        if ( !settingsStyleInAvailableStyles && (settingStyle == style)) {
-            m_styleModel->addStyle(Style(Style(style + tr(" (unavailable, fallback to Default)"), style)));
-        }
-        else {
-            if (style == "System_Auto")
-                m_styleModel->addStyle(Style(tr("Style of system"), style));
-            else if (style == "Default")
-                m_styleModel->addStyle(Style("Default" + tr(" (Recommended)"), style));
-            else
-                m_styleModel->addStyle(Style(style, style));
-        }
-    }
-    return m_styleModel;
-}
-
-QHash<int, QByteArray> StyleModel::roleNames() const
-{
-    QHash<int, QByteArray> roles;
-    roles[LabelRole] = "label";
-    roles[StyleRole] = "style";
-    return roles;
-}
-
-Style::Style(const QString &label, const QString &style)
-    : m_label(label), m_style(style)
-{
-}
-
-QString Style::label() const
-{
-    return m_label;
-}
-
-QString Style::style() const
-{
-    return m_style;
-}
-
-void StyleModel::addStyle(const Style &style)
-{
-    beginInsertRows(QModelIndex(), rowCount(), rowCount());
-    m_styles << style;
-    endInsertRows();
-}
-
-int StyleModel::rowCount(const QModelIndex & parent) const
-{
-    Q_UNUSED(parent);
-    return m_styles.count();
-}
-
-QVariantMap StyleModel::get(int row) const
-{
-    QHash<int,QByteArray> names = roleNames();
-    QHashIterator<int, QByteArray> i(names);
-    QVariantMap res;
-    QModelIndex idx = index(row, 0);
-    while (i.hasNext()) {
-        i.next();
-        QVariant data = idx.data(i.key());
-        res[i.value()] = data;
-    }
-    return res;
-}
-
-QVariant StyleModel::data(const QModelIndex & index, int role) const
-{
-    if (index.row() < 0 || index.row() >= m_styles.count())
-        return QVariant();
-
-    const Style &style = m_styles[index.row()];
-    if (role == LabelRole)
-        return style.label();
-    else if (role == StyleRole)
-        return style.style();
-    return QVariant();
-}
 
 #ifndef __ANDROID__
 void CGUIHelper::updateMprisStationList(QString serializedJson, QString listType, int index)
